@@ -77,6 +77,7 @@ struct binfmt *binfmt_load (const char *name, const char *filename, int quiet)
     READ_LINE (detector, 1);
     READ_LINE (credentials, 1);
     READ_LINE (preserve, 1);
+    READ_LINE (fix_binary, 1);
 
 #undef READ_LINE
 
@@ -108,6 +109,7 @@ struct binfmt *binfmt_new (const char *name, Hash_table *args)
     SET_FIELD (detector);
     SET_FIELD (credentials);
     SET_FIELD (preserve);
+    SET_FIELD (fix_binary);
 
 #undef SET_FIELD
 
@@ -182,6 +184,7 @@ int binfmt_write (const struct binfmt *binfmt, const char *filename)
     WRITE_FIELD (detector);
     WRITE_FIELD (credentials);
     WRITE_FIELD (preserve);
+    WRITE_FIELD (fix_binary);
 
 #undef WRITE_FIELD
 
@@ -207,6 +210,7 @@ void binfmt_print (const struct binfmt *binfmt)
     PRINT_FIELD (detector);
     PRINT_FIELD (credentials);
     PRINT_FIELD (preserve);
+    PRINT_FIELD (fix_binary);
 
 #undef PRINT_FIELD
 }
@@ -231,6 +235,7 @@ void binfmt_free (struct binfmt *binfmt)
     free (binfmt->detector);
     free (binfmt->credentials);
     free (binfmt->preserve);
+    free (binfmt->fix_binary);
     free (binfmt);
 }
 
