@@ -363,6 +363,7 @@ static int act_enable (const char *name)
 	const char *interpreter;
 	const char *credentials;
 	const char *preserve;
+	const char *fix_binary;
 	char *regstring;
 
 	procdir_name = xasprintf ("%s/%s", procdir, name);
@@ -417,10 +418,13 @@ static int act_enable (const char *name)
 		? "C" : "";
 	preserve = (binfmt->preserve && !strcmp (binfmt->preserve, "yes"))
 		? "P" : "";
-	regstring = xasprintf (":%s:%c:%s:%s:%s:%s:%s%s\n",
+	fix_binary =
+		(binfmt->fix_binary && !strcmp (binfmt->fix_binary, "yes"))
+		? "F" : "";
+	regstring = xasprintf (":%s:%c:%s:%s:%s:%s:%s%s%s\n",
 			       name, type, binfmt->offset, binfmt->magic,
 			       binfmt->mask, interpreter,
-			       credentials, preserve);
+			       credentials, preserve, fix_binary);
 	if (test)
 	    printf ("enable %s with the following format string:\n %s",
 		    name, regstring);
@@ -808,6 +812,7 @@ enum opts {
     OPT_DETECTOR,
     OPT_CREDENTIALS,
     OPT_PRESERVE,
+    OPT_FIX_BINARY,
     OPT_PACKAGE,
     OPT_ADMINDIR,
     OPT_IMPORTDIR,
@@ -850,6 +855,9 @@ static struct argp_option options[] = {
 	"use credentials of original binary for interpreter (yes/no)" },
     { "preserve",	OPT_PRESERVE, "YES/NO",	OPTION_HIDDEN,
 	"preserve argv[0] of original binary for interpreter (yes/no)" },
+    { "fix-binary",	OPT_FIX_BINARY,	"YES/NO",	OPTION_HIDDEN,
+	"open interpreter binary immediately and always use open image "
+	"(yes/no)" },
     { "package",	OPT_PACKAGE,	"PACKAGE-NAME",	0,
 	"for --install and --remove, specify the current package name", 1 },
     { "admindir",	OPT_ADMINDIR,	"DIRECTORY",	0,
@@ -876,6 +884,7 @@ static struct {
     const char *detector;
     const char *credentials;
     const char *preserve;
+    const char *fix_binary;
 } spec;
 
 static const char *mode_name (enum opts m)
@@ -1004,6 +1013,10 @@ static error_t parse_opt (int key, char *arg, struct argp_state *state)
 	    spec.preserve = arg;
 	    return 0;
 
+	case OPT_FIX_BINARY:
+	    spec.fix_binary = arg;
+	    return 0;
+
 	case OPT_PACKAGE:
 	    if (package)
 		argp_error (state, "more than one --package option given");
@@ -1116,6 +1129,7 @@ int main (int argc, char **argv)
 	ADD_SPEC (detector);
 	ADD_SPEC (credentials);
 	ADD_SPEC (preserve);
+	ADD_SPEC (fix_binary);
 #undef ADD_SPEC
 	binfmt = binfmt_new (name, format_args);
 
